@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Systemd;
-$Config::Model::Systemd::VERSION = '0.002';
+$Config::Model::Systemd::VERSION = '0.003';
 use 5.10.1;
 
 use Config::Model 2.083;
@@ -29,7 +29,7 @@ Config::Model::Systemd - Edit and validate Systemd configuration files
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -69,7 +69,7 @@ You can also use L<cme> to run sanity checks on the configuration file:
  cme check systemd-user
  cme check systemd
 
-=comment
+=begin :comment
 
 =head2 Fix warnings
 
@@ -78,7 +78,7 @@ You can choose to  fix (most of) these warnings with the command:
 
  cme fix systemd-user
 
-=end comment
+=end :comment
 
 =head1 BUGS
 
